@@ -41,6 +41,7 @@
 #include "tcpstate.h"
 #include "network.h"
 #include "dumper.h"
+#include "pcaps.h"
 
 #include <ldns/ldns.h>
 
@@ -630,6 +631,8 @@ void parse_args(int argc, char* argv[])
                 (*pl->extension)(DNSCAP_EXT_SET_OUTPUT_PKT, (set_output_pkt_t)set_output_pkt);
                 (*pl->extension)(DNSCAP_EXT_GET_PCAP_THREAD_FTELL, (get_pcap_thread_ftell_t)_get_pcap_thread_ftell);
                 (*pl->extension)(DNSCAP_EXT_GET_PKTHDR_CAPLEN, (get_pkthdr_caplen_t)_get_pkthdr_caplen);
+                (*pl->extension)(DNSCAP_EXT_BREAKLOOP_PCAPS, (breakloop_pcaps_t)breakloop_pcaps);
+                (*pl->extension)(DNSCAP_EXT_GET_LAST_TOTAL_COMPRESS_READ, (get_last_total_compress_read_t)get_last_total_compress_read);
             }
             snprintf(sn, sizeof(sn), "%s_getopt", pl->name);
             pl->getopt = dlsym(pl->handle, sn);
@@ -699,8 +702,10 @@ void parse_args(int argc, char* argv[])
             usage("unrecognized command line option");
         }
     }
-    assert(msg_wanted != 0U);
-    assert(err_wanted != 0U);
+    if (!msg_wanted)
+        usage("empty -m \"\" not allowed");
+    if (!err_wanted)
+        usage("empty -e \"\" not allowed");
     if (dump_type == nowhere && !preso && EMPTY(plugins))
         usage("without -w or -g, there would be no output");
     if (end_hide != 0U && wantfrags)
