@@ -54,6 +54,10 @@
 #endif
 #endif
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /*
  * setup MY_BPFTIMEVAL as the timeval structure that bpf packets
  * will be assoicated with packets from libpcap
@@ -154,6 +158,12 @@ typedef long (*get_pcap_thread_ftell_t)(void);
 #define DNSCAP_EXT_GET_PKTHDR_CAPLEN 8
 typedef size_t (*get_pkthdr_caplen_t)(void);
 
+#define DNSCAP_EXT_BREAKLOOP_PCAPS 9
+typedef void (*breakloop_pcaps_t)(void);
+
+#define DNSCAP_EXT_GET_LAST_TOTAL_COMPRESS_READ 10
+typedef size_t (*get_last_total_compress_read_t)(void);
+
 /*
  * Flags
  */
@@ -169,4 +179,8 @@ typedef size_t (*get_pkthdr_caplen_t)(void);
 #define DIR_INITIATE 0x0001
 #define DIR_RESPONSE 0x0002
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* __dnscap_dnscap_common_h */
