@@ -135,10 +135,6 @@ void layer_pkt(u_char* user, const pcap_thread_packet_t* packet, const u_char* p
     if (main_exit)
         return;
 
-    /* If ever SNAPLEN wasn't big enough, we have no recourse. */
-    if (firstpkt->pkthdr.len != firstpkt->pkthdr.caplen)
-        return;
-
     vlan = MAX_VLAN;
     for (prevpkt = packet; prevpkt; prevpkt = prevpkt->prevpkt) {
         if (prevpkt->have_ieee802hdr) {
@@ -283,10 +279,6 @@ void dl_pkt(u_char* user, const struct pcap_pkthdr* hdr, const u_char* pkt, cons
     if (main_exit)
         return;
 
-    /* If ever SNAPLEN wasn't big enough, we have no recourse. */
-    if (hdr->len != hdr->caplen)
-        return;
-
     pkthdr_caplen = hdr->caplen;
 
     /* Data link. */
@@ -1041,6 +1033,11 @@ void network_pkt2(const char* descr, my_bpftimeval ts, const pcap_thread_packet_
             int match_tc    = (dns.tc != 0 && err_wanted & ERR_TRUNC);
             int match_rcode = err_wanted & (ERR_RCODE_BASE << dns.rcode);
 
+            if (!match_tc && (err_wanted & ERR_NO) && dns.tc) {
+                // special case since TC bit is not parts of rcode, but still considered an error
+                // if TC not selected and ERR_NO is, filter away ERR_NO if truncated
+                match_rcode &= ~ERR_NO;
+            }
             if (!match_tc && !match_rcode) {
                 tcpstate_discard(tcpstate, "unwanted error code");
                 return;
@@ -1619,6 +1616,11 @@ void network_pkt(const char* descr, my_bpftimeval ts, unsigned pf,
             int match_tc    = (dns.tc != 0 && err_wanted & ERR_TRUNC);
             int match_rcode = err_wanted & (ERR_RCODE_BASE << dns.rcode);
 
+            if (!match_tc && (err_wanted & ERR_NO) && dns.tc) {
+                // special case since TC bit is not parts of rcode, but still considered an error
+                // if TC not selected and ERR_NO is, filter away ERR_NO if truncated
+                match_rcode &= ~ERR_NO;
+            }
             if (!match_tc && !match_rcode) {
                 tcpstate_discard(tcpstate, "unwanted error code");
                 goto network_pkt_end;
