@@ -44,4 +44,8 @@ void breakloop_pcaps(void);
 void close_pcaps(void);
 void do_pcap_stats();
 
+extern size_t last_total_compress_read;
+
+size_t get_last_total_compress_read();
+
 #endif /* __dnscap_pcaps_h */
