@@ -4,7 +4,9 @@ txtout="../../plugins/txtout/.libs/txtout.so"
 
 rm -f test7.out test7.layer.out
 
-for what in dnso1tcp.pcap-dist 1qtcpnosyn.pcap-dist do1t-nosyn-1nolen.pcap-dist dnso1tcp-midmiss.pcap-dist; do
+for what in dnso1tcp.pcap 1qtcpnosyn.pcap do1t-nosyn-1nolen.pcap dnso1tcp-midmiss.pcap; do
+    test -e "$what" || ln -s "$srcdir/$what" "$what"
+
     ../dnscap -r "$what" -g -T 2>>test7.out
     ../dnscap -r "$what" -g -T -o use_layers=yes 2>>test7.layer.out
     if [ -f "$txtout" ]; then
@@ -20,7 +22,9 @@ echo "" >>test7.layer.out
 echo "Enabling parse_ongoing_tcp and allow_reset_tcpstate" >>test7.layer.out
 echo "" >>test7.layer.out
 
-for what in dnso1tcp.pcap-dist 1qtcpnosyn.pcap-dist do1t-nosyn-1nolen.pcap-dist dnso1tcp-midmiss.pcap-dist; do
+for what in dnso1tcp.pcap 1qtcpnosyn.pcap do1t-nosyn-1nolen.pcap dnso1tcp-midmiss.pcap; do
+    test -e "$what" || ln -s "$srcdir/$what" "$what"
+
     ../dnscap -r "$what" -g -T -o parse_ongoing_tcp=yes -o allow_reset_tcpstate=yes 2>>test7.out
     ../dnscap -r "$what" -g -T -o parse_ongoing_tcp=yes -o allow_reset_tcpstate=yes -o use_layers=yes 2>>test7.layer.out
     if [ -f "$txtout" ]; then
